<?php

class WP_Widget_Trtaxonomies extends WP_Widget {

	public function __construct() {
		$widget_ops = array('classname' => 'widget_trtaxonomies', 'description' => __( "Widget to list with taxonomies best design", TR_THEMENAMEOPTIONS) );
		parent::__construct('tr-taxonomies', __('TR Taxonomies', TR_THEMENAMEOPTIONS), $widget_ops);
		$this->alt_option_name = 'widget_trtaxonomies';
	}

	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'CATEGORIES', TR_THEMENAME );

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $taxb = $instance['tax'];
		$show_galleries = isset( $instance['show_galleries'] ) ? $instance['show_galleries'] : false;
		$show_videos = isset( $instance['show_videos'] ) ? $instance['show_videos'] : false;
		$tr_empty = $instance['tr_empty'];
		$url = $instance['url'];
?>
        <div class="TtBxCn">
            <?php if ( $title ) { ?>
            <div class="TtBxTp"><?php echo $title; ?></div>
            <?php } ?>
            <ul class="ListTop">
                <?php
                    $i=1;
                    $taxonomies = get_categories( array(
                        'orderby' => 'name',
                        'taxonomy' => $taxb,
                        'hide_empty' => $tr_empty
                    ) );

                    foreach ( $taxonomies as $tax ) {
                        
                        echo '<li data-topnum="'.$i.'"><a href="'.esc_url( get_category_link( $tax->term_id ) ).'">'.esc_html( $tax->name ).'</a>'; echo'<span>'; 

                        if($show_galleries and $taxb=='category'){ 
                            echo'<span class="fa-picture-o">'.tr_count_gallery_or_videos_category($tax->term_id, 2).'</span>'; 
                        }elseif($show_galleries and $taxb==tr_config('pornostar_slug')){ 
                            echo'<span class="fa-picture-o">'.tr_count_pornstar($tax->term_id, 2, TRUE).'</span>'; 
                        }
                        
                        if($show_videos and $taxb=='category'){ 
                            echo'<span class="fa-film">'.tr_count_gallery_or_videos_category($tax->term_id, 1).'</span>'; 
                        }elseif($show_videos and $taxb==tr_config('pornostar_slug')){ 
                            echo'<span class="fa-film">'.tr_count_pornstar($tax->term_id, 1, TRUE).'</span>'; 
                        }
                        
                        echo'</span>'; echo'</li>';
                        
                        $i++;
                    }
                ?>
            </ul>
            <?php if($url!=''){ ?>
            <a href="<?php echo $url; ?>" class="More fa-plus-circle"></a>
            <?php } ?>
        </div>
<?php
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['tax'] = strip_tags( $new_instance['tax'] );
		$instance['show_galleries'] = isset( $new_instance['show_galleries'] ) ? (bool) $new_instance['show_galleries'] : false;
		$instance['show_videos'] = isset( $new_instance['show_videos'] ) ? (bool) $new_instance['show_videos'] : false;
		$instance['tr_empty'] = empty($new_instance['tr_empty']) ? 1 : 0 ;
		$instance['url'] = sanitize_text_field( $new_instance['url'] );
		return $instance;
	}

	public function form( $instance ) {
		$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$tax = isset( $instance['tax'] ) ? esc_attr( $instance['tax'] ) : 'category';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_galleries = isset( $instance['show_galleries'] ) ? (bool) $instance['show_galleries'] : false;
		$show_videos = isset( $instance['show_videos'] ) ? (bool) $instance['show_videos'] : false;
		$tr_empty = isset( $instance['tr_empty'] ) ? (bool) $instance['tr_empty'] : false;
		$url = isset( $instance['url'] ) ? esc_attr( $instance['url'] ) : '';
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>
		
        <p><label for="<?php echo $this->get_field_id('tax'); ?>"><?php _e('Taxonomy', TR_THEMENAMEOPTIONS); ?></label></p>
        <p>
            <select id="<?php echo $this->get_field_id('tax'); ?>" name="<?php echo $this->get_field_name('tax'); ?>">
                <option <?php selected( $tax, 'category' ) ?> value="category"><?php _e('Categories', TR_THEMENAMEOPTIONS); ?></option>
                <option <?php selected( $tax, tr_config('pornostar_taxonomy') ) ?> value="<?php tr_config('pornostar_slug', TRUE); ?>"><?php _e('Pornstars', TR_THEMENAMEOPTIONS); ?></option>
            </select>
        </p>
        
		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:' ); ?></label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" /></p>
		
		<p><input class="checkbox" type="checkbox"<?php checked( $show_galleries ); ?> id="<?php echo $this->get_field_id( 'show_galleries' ); ?>" name="<?php echo $this->get_field_name( 'show_galleries' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_galleries' ); ?>"><?php _e( 'Show number of gallaeries?', TR_THEMENAMEOPTIONS ); ?></label></p>
		
		<p><input class="checkbox" type="checkbox"<?php checked( $show_videos ); ?> id="<?php echo $this->get_field_id( 'show_videos' ); ?>" name="<?php echo $this->get_field_name( 'show_videos' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_videos' ); ?>"><?php _e( 'Show number of videos?', TR_THEMENAMEOPTIONS ); ?></label></p>
		
		<p><input class="checkbox" type="checkbox"<?php checked( '', $tr_empty ); ?> id="<?php echo $this->get_field_id( 'tr_empty' ); ?>" name="<?php echo $this->get_field_name( 'tr_empty' ); ?>" value="1" />
		<label for="<?php echo $this->get_field_id( 'tr_empty' ); ?>"><?php _e( 'Show empty taxonomy?', TR_THEMENAMEOPTIONS ); ?></label></p>
		
		<p><label for="<?php echo $this->get_field_id( 'url' ); ?>"><?php _e( 'View more:', TR_THEMENAMEOPTIONS ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" type="text" value="<?php echo $url; ?>" /></p>
<?php
	}
}