<?php

class WP_Widget_Trposts extends WP_Widget {

	public function __construct() {
		$widget_ops = array('classname' => 'widget_trposts', 'description' => __( "Widget to display posts ordered in different ways: past, voted, visited...", TR_THEMENAMEOPTIONS) );
		parent::__construct('tr-posts', __('TR Posts', TR_THEMENAMEOPTIONS), $widget_ops);
		$this->alt_option_name = 'widget_trposts';
	}

	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'TR Posts', TR_THEMENAME );

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;
		$order = isset( $instance['order'] ) ? $instance['order'] : 1;
        $filter = $instance['filter'];
        
        if($order==1){

            $r = new WP_Query( apply_filters( 'widget_posts_args', array(
                'posts_per_page'      => $number,
                'no_found_rows'       => true,
                'post_status'         => 'publish',
                'ignore_sticky_posts' => true,
                'cat' => $filter,
                'order' => 'DESC',
                'orderby' => 'date',
            ) ) );
            
        }elseif($order==2){
            
            $r = new WP_Query( apply_filters( 'widget_posts_args', array(
                'posts_per_page'      => $number,
                'no_found_rows'       => true,
                'post_status'         => 'publish',
                'ignore_sticky_posts' => true,
                'cat' => $filter,
                'meta_key' => 'views',
                'orderby' => 'meta_value_num',
            ) ) );
            
        }elseif($order==3){
            
            $r = new WP_Query( apply_filters( 'widget_posts_args', array(
                'posts_per_page'      => $number,
                'no_found_rows'       => true,
                'post_status'         => 'publish',
                'ignore_sticky_posts' => true,
                'cat' => $filter,
                'meta_key' => 'trrating_type1',
                'orderby' => 'meta_value_num',
            ) ) );

        }else{
            
            $r = new WP_Query( apply_filters( 'widget_posts_args', array(
                'posts_per_page'      => $number,
                'no_found_rows'       => true,
                'post_status'         => 'publish',
                'ignore_sticky_posts' => true,
                'cat' => $filter,
                'orderby' => 'rand',
            ) ) );

        }

		if ($r->have_posts()) :
		?>
        <div class="TtBxCn Dark">
            <?php if ( $title ) { ?>
            <div class="TtBxTp"><?php echo $title; ?></div>
            <?php } ?>
            <div class="TtScrollD">
                <ul class="ListRandomPost TtStyC">
		<?php while ( $r->have_posts() ) : $r->the_post(); ?>
            <!--<Post>-->
            <li>
                <article class="Post AX Cols Row AFluid">
                    <div class="Picture">
                        <figure><a<?php tr_permalink_attr(1, get_the_ID()); ?> rel="bookmark" href="<?php the_permalink(); ?>"><?php echo tr_theme_img(get_the_ID(), 'tbwidget', get_the_title()); ?></a></figure>
                    </div>
                    <header>
                        <h2 class="Title"><a<?php tr_permalink_attr(1, get_the_ID()); ?> rel="bookmark" href="<?php the_permalink(); ?>"><?php echo tr_theme_clip_text(get_the_title(), 20); ?></a></h2>
                        <div class="Info">
                            <span class="CateLink fa-folder-open Clr2B"><?php tr_category_list_limit(get_the_ID(), 1); ?></span>
                            <span><?php echo tr_theme_duration_or_count(get_the_ID()); ?> <?php tr_theme_rating_percentage(get_the_ID()); ?></span>
                        </div>
                    </header>
                </article>
            </li>
            <!--</Post>-->						
		<?php endwhile; ?>
                </ul>
            </div>
        </div>
		<?php
		wp_reset_postdata();

		endif;
	}

	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];
		$instance['order'] = isset( $new_instance['order'] ) ? (int) $new_instance['order'] : false;
        $instance['filter'] = strip_tags(implode(',', $new_instance['filter']));
		return $instance;
	}

	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$order = isset( $instance['order'] ) ? (int) $instance['order'] : false;
		$filter = isset($instance['filter']) ? $instance['filter'] :false;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:' ); ?></label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" /></p>

        <p>
            <label for="<?php echo $this->get_field_id('order'); ?>"><?php _e('Order', TR_THEMENAMEOPTIONS); ?></label>
            <select id="<?php echo $this->get_field_id('order'); ?>" name="<?php echo $this->get_field_name('order'); ?>">
                <option<?php selected($order, 1 ); ?> value="1"><?php _e('Latest', TR_THEMENAMEOPTIONS); ?></option>
                <option<?php selected($order, 2 ); ?> value="2"><?php _e('Views (Require WP-PostViews)', TR_THEMENAMEOPTIONS); ?></option>
                <option<?php selected($order, 3 ); ?> value="3"><?php _e('Best rated', TR_THEMENAMEOPTIONS); ?></option>
                <option<?php selected($order, 4 ); ?> value="4"><?php _e('Random', TR_THEMENAMEOPTIONS); ?></option>
            </select>                
        </p>
        
		<p><?php _e('Filter categories', TR_THEMENAMEOPTIONS); ?></p>
		<ul>
            <?php
            $lst=''; $ar='';
        
                $ar=explode(',', $filter);
                foreach ($ar as &$value) {
                    $lst[$value] = $value;
                }
                $categories = get_categories('hide_empty=0');
                foreach ($categories as $category) {
            ?>
		    <li>
		        <input <?php if(isset($lst[$category->term_id])){checked( $lst[$category->term_id], $category->term_id); } ?> type="checkbox" class="checkbox" name="<?php echo $this->get_field_name('filter'); ?>[]" value="<?php echo $category->term_id; ?>"  />
		        <label><?php echo $category->cat_name ?></label><br />
		    </li>
		    <?php
                }
            ?>
		</ul>
<?php
	}
}